yt.config.YTConfigParser.read — The yt Project 3.2-dev documentation

# yt.config.YTConfigParser.read

`YTConfigParser.` `read`(filenames)

  Read and parse a filename or a list of filenames.

  Files that cannot be opened are silently ignored; this is designed so that you can specify a list of potential configuration file locations (e.g. current directory, user’s home directory, systemwide directory), and all existing configuration files in the list will be read. A single filename may also be given.

  Return list of successfully read files.